==> central-repository-3.59.0.zip: sun/net/ProgressListener.java <==
/*
 * Copyright (c) 2004, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2014-2019 MicroEJ Corp. - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.net;

import java.util.EventListener;

/**
 * ProgressListener is an interface to be implemented by parties
 * interested to be notified of progress in network input stream.
 *
 * @author Stanley Man-Kit Ho
 */
public interface ProgressListener extends EventListener
{
    /**
     * Start progress.
     */
    public void progressStart(ProgressEvent evt);

    /**
     * Update progress.
     */
    public void progressUpdate(ProgressEvent evt);

    /**
     * Finish progress.
     */
    public void progressFinish(ProgressEvent evt);
}

==> central-repository-3.62.0.zip: sun/net/ProgressListener.java <==
/*
 * Copyright (c) 2004, Oracle and/or its affiliates. All rights reserved.
 * Copyright (C) 2014-2020 MicroEJ Corp. - EDC compliance and optimizations.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.net;

import java.util.EventListener;

/**
 * ProgressListener is an interface to be implemented by parties interested to be notified of progress in network input
 * stream.
 *
 * @author Stanley Man-Kit Ho
 */
public interface ProgressListener extends EventListener {
	/**
	 * Start progress.
	 */
	public void progressStart(ProgressEvent evt);

	/**
	 * Update progress.
	 */
	public void progressUpdate(ProgressEvent evt);

	/**
	 * Finish progress.
	 */
	public void progressFinish(ProgressEvent evt);
}
